{% extends "base.jinja.html" %}
{% block title %}Table{% endblock %}
{% block viewtype %}table-view{% endblock %}

{% block content %}

      {% include "_shared/tags.jinja.html" %}

      <div class="content">

        {%- if document.free_texts -%}
        <section data-col="0">
          {%- for free_text in document.free_texts -%}
          <div class="free-text">
            {{ renderer.render_free_text(free_text) }}
          </div>
          {%- endfor -%}
        </section>
        {%- endif -%}

      {%- for section_or_requirement in document_iterator.all_content() %}

        {%- if section_or_requirement.is_composite_requirement %}

          {%- set requirement = section_or_requirement %}
          {% with anchor=link_renderer.render(section_or_requirement) -%}
          {% include "_shared/requirement.jinja.html" %}
          {%- endwith %}

        {%- elif section_or_requirement.is_requirement %}

          {%- set requirement = section_or_requirement %}
          {% with anchor=link_renderer.render(section_or_requirement) -%}
          {% include "_shared/requirement.jinja.html" %}
          {%- endwith %}

        {%- elif section_or_requirement.is_section %}

          {%- set section = section_or_requirement %}
          {% with anchor=link_renderer.render(section_or_requirement) -%}
          {% include "_shared/docsection.jinja.html" %}
          {%- endwith %}

        {%- endif %}

      {%- endfor %}
      </div>

{% endblock content %}
