<!DOCTYPE html>
<html lang="en">

<head>
  {% block head %}
  <meta charset="UTF-8"/>
  <link rel="shortcut icon" href="/favicon.ico" type="image/x-icon"/>
  <link rel="icon" href="/favicon.ico" type="image/x-icon"/>
  {% block head_css %}
  <link rel="stylesheet" href="{{document.meta.get_root_path_prefix()}}/_static/_base.css"/>
  <link rel="stylesheet" href="{{document.meta.get_root_path_prefix()}}/_static/_layout.css"/>
  <link rel="stylesheet" href="{{document.meta.get_root_path_prefix()}}/_static/_content.css"/>
  <link rel="stylesheet" href="{{document.meta.get_root_path_prefix()}}/_static/_element.css"/>
  {% endblock head_css %}
  {% block head_scripts %}
  <script type="text/javascript" src="{{document.meta.get_root_path_prefix()}}/_static/toc.js"></script>
  {% endblock head_scripts %}
  <title>{{document.name}} - {% block title %}{% endblock title %}</title>
  {% endblock head %}
</head>

<body class="{% block viewtype %}{% endblock %}">

  {%- set document_iterator = traceability_index.get_document_iterator(document) -%}

  <div class="layout" id="layout">

    <aside class="layout_aside-header">
      <div>Table of Contents</div>
      <a class="index-link" href="{{document.meta.get_root_path_prefix()}}/index.html">To Index</a>
    </aside>

    <aside class="layout_aside">
      {% include "_shared/toc.jinja.html" %}
    </aside>

    <a class="layout_toggler layout_button" id="layout_toggle"></a>

    <nav class="layout_nav">
      <a
      class="layout_nav-btn layout_button btn-document"
      title="Go to Document view"
      href="{{document.meta.get_root_path_prefix()}}/{{document.meta.get_html_doc_link()}}">
      DOC
    </a>
    <a
      class="layout_nav-btn layout_button btn-table"
      title="Go to Table view"
      href="{{document.meta.get_root_path_prefix()}}/{{document.meta.get_html_table_link()}}">
      TBL
    </a>
    <a
      class="layout_nav-btn layout_button btn-traceability"
      title="Go to Traceability view"
      href="{{document.meta.get_root_path_prefix()}}/{{document.meta.get_html_traceability_link()}}">
      TR
    </a>
    <a
      class="layout_nav-btn layout_button btn-deep-traceability"
      title="Go to Deep Traceability view"
      href="{{document.meta.get_root_path_prefix()}}/{{document.meta.get_html_deep_traceability_link()}}">
      DTR
    </a>
    </nav>

    <header class="layout_header">
      <p>{{document.name}} <span class="document-view-type">{{ self.title() }}</span></p>
    </header>

    <main class="layout_main">
      {% block content %}{% endblock %}
    </main>

  </div>
  {% block scripts %}{% endblock %}
</body>
</html>